var _interopRequireDefault=require("@babel/runtime/helpers/interopRequireDefault");Object.defineProperty(exports,"__esModule",{value:true});exports.checkIfTemplateInstalled=exports.applyLocalTemplate=exports.applyTemplate=exports.getTemplateOptions=exports.addTemplate=exports.listTemplates=void 0;var _chalk=_interopRequireDefault(require("chalk"));
var _fs=_interopRequireDefault(require("fs"));
var _path=_interopRequireDefault(require("path"));
var _constants=require("../constants");
var _exec=require("../systemTools/exec");
var _fileutils=require("../systemTools/fileutils");




var _common=require("../common");
var _pluginTools=require("../pluginTools");
var _configParser=require("../configTools/configParser");

var _templates=require("../../renativeTemplates/templates.json");

var listTemplates=function listTemplates(c){return new Promise(function(resolve,reject){
(0,_common.logTask)('listTemplates');
opts=(0,_common.generateOptions)(_templates.templates);
console.log(opts.asString);
resolve();
});};exports.listTemplates=listTemplates;

var addTemplate=function addTemplate(c){return new Promise(function(resolve,reject){
(0,_common.logTask)('addTemplate');
(0,_exec.executeAsync)('npm',['install','renative-template-hello-world','--save-dev']).
then(function(){
resolve();
}).
catch(function(error){return(0,_common.logError)(error);});
});};exports.addTemplate=addTemplate;

var checkIfTemplateInstalled=function checkIfTemplateInstalled(c){return new Promise(function(resolve,reject){
(0,_common.logTask)('checkIfTemplateInstalled');
if(!c.buildConfig.defaults){
(0,_common.logWarning)("Your "+_chalk.default.white(c.paths.project.config)+" does not contain "+_chalk.default.white('defaultProjectConfigs')+" object. ReNative will skip template generation");
resolve();
return;
}

var templateName=c.buildConfig.defaults.template;
if(!templateName){
templateName='renative-template-hello-world';
(0,_common.logWarning)("You're missing template name in your "+_chalk.default.white(c.paths.project.config)+". ReNative will add default "+_chalk.default.white(templateName)+" for you");
c.buildConfig.defaults.template=templateName;
_fs.default.writeFileSync(c.paths.project.config,JSON.stringify(c.files.project.config,null,2));
}

c.paths.templateFolder=_path.default.join(c.paths.project.nodeModulesDir,templateName);
if(!_fs.default.existsSync(c.paths.templateFolder)){
(0,_common.logWarning)("Your "+_chalk.default.white(c.paths.templateFolder)+" template is not installed. ReNative will install it for you");

if(c.files.project.package.devDependencies){
if(!c.files.project.package.devDependencies[templateName]){
c.files.project.package.devDependencies[templateName]='latest';
(0,_fileutils.writeObjectSync)(c.paths.project.package,c.files.project.package);
}
}

c._requiresNpmInstall=true;
}
resolve();
});};exports.checkIfTemplateInstalled=checkIfTemplateInstalled;

var _applyLocalRenative=function _applyLocalRenative(c){return new Promise(function(resolve,reject){
if(!c.runtime.isWrapper){
resolve();
return;
}

if(c.buildConfig.plugins.renative){
c.buildConfig.plugins.renative=(0,_pluginTools.getLocalRenativePlugin)();
}
(0,_fileutils.writeObjectSync)(c.paths.project.config,c.buildConfig);
resolve();
});};


var applyLocalTemplate=function applyLocalTemplate(c,selectedTemplate){return new Promise(function(resolve,reject){
(0,_common.logTask)("applyLocalTemplate:"+selectedTemplate);
var currentTemplate=c.buildConfig.defaults.template;
if(selectedTemplate){
(0,_common.logTask)("applyTemplate:"+selectedTemplate);

if(currentTemplate!==selectedTemplate){
(0,_common.logWarning)("Current template "+_chalk.default.red(currentTemplate)+" will be overriden by "+_chalk.default.green(selectedTemplate));
}

var dirsToRemove=[
_path.default.join(c.paths.project.projectConfig.dir),
_path.default.join(c.paths.project.srcDir),
_path.default.join(c.paths.project.appConfigsDir)];


var filesToRemove=c.buildConfig.defaults.supportedPlatforms.map(function(p){return _path.default.join(c.paths.project.dir,"index."+p+".js");});

(0,_fileutils.removeDirsSync)(dirsToRemove);

(0,_fileutils.removeFilesSync)(filesToRemove);

c.paths.projectTemplateFolder=_path.default.join(c.paths.project.nodeModulesDir,selectedTemplate);

_applyTemplate(c).
then(function(){return(0,_common.configureEntryPoints)(c);}).
then(function(){return _applyLocalRenative(c);}).
then(function(){return resolve();}).
catch(function(e){return reject(e);});
}
});};exports.applyLocalTemplate=applyLocalTemplate;

var applyTemplate=function applyTemplate(c){return new Promise(function(resolve,reject){
(0,_common.logTask)('applyTemplate');
var currentTemplate=c.buildConfig.defaults.template;

if(!c.buildConfig.defaults){
reject("Your "+_constants.RENATIVE_CONFIG_NAME+" is missing defaultProjectConfigs object");
return;
}

c.paths.projectTemplateFolder=_path.default.join(c.paths.project.nodeModulesDir,c.buildConfig.defaults.template);

_applyTemplate(c).


then(function(){return resolve();}).
catch(function(e){return reject(e);});
});};exports.applyTemplate=applyTemplate;

var _applyTemplate=function _applyTemplate(c){return new Promise(function(resolve,reject){
(0,_common.logTask)("_applyTemplate:"+c.paths.projectTemplateFolder);


if(!_fs.default.existsSync(c.paths.projectTemplateFolder)){
(0,_common.logWarning)("Template "+_chalk.default.white(c.buildConfig.defaults.template)+" does not exist in your "+_chalk.default.white(c.paths.projectTemplateFolder)+". skipping");
resolve();
return;
}

var templateAppConfigsFolder=_path.default.join(c.paths.projectTemplateFolder,'appConfigs');
var templateAppConfigFolder=_fs.default.readdirSync(templateAppConfigsFolder)[0];
var templateProjectConfigFolder=_path.default.join(c.paths.projectTemplateFolder,'projectConfig');

if(templateAppConfigFolder)c.defaultAppConfigId=templateAppConfigFolder;


(0,_common.logTask)('configureProject:check src',_chalk.default.grey);
if(!_fs.default.existsSync(c.paths.project.srcDir)){
(0,_common.logWarning)("Looks like your src folder "+_chalk.default.white(c.paths.project.srcDir)+" is missing! Let's create one for you.");
(0,_fileutils.copyFolderContentsRecursiveSync)(_path.default.join(c.paths.projectTemplateFolder,'src'),c.paths.project.srcDir);
}


(0,_common.logTask)('configureProject:check appConfigs',_chalk.default.grey);
(0,_configParser.setAppConfig)(c,c.defaultAppConfigId);
if(!_fs.default.existsSync(c.paths.project.appConfigsDir)){
(0,_common.logWarning)("Looks like your appConfig folder "+
_chalk.default.white(
c.paths.project.appConfigsDir)+" is missing! Let's create sample config for you.");





(0,_fileutils.copyFolderContentsRecursiveSync)(templateAppConfigsFolder,c.paths.project.appConfigsDir);



try{
var appConfig=JSON.parse(_fs.default.readFileSync(c.paths.appConfig.config).toString());

appConfig.common.title=c.buildConfig.defaults.defaultTitle||c.files.project.package.title;
appConfig.common.id=c.buildConfig.defaults.defaultAppId||c.files.project.package.defaultAppId;
appConfig.id=c.buildConfig.defaults.defaultAppConfigId||c.defaultAppConfigId;
appConfig.platforms.ios.teamID='';
appConfig.platforms.tvos.teamID='';

var supPlats=c.buildConfig.defaults.supportedPlatforms;

if(supPlats){
for(var pk in appConfig.platforms){
if(!supPlats.includes(pk)){
delete appConfig.platforms[pk];
}
}
}

_fs.default.writeFileSync(c.paths.appConfig.config,JSON.stringify(appConfig,null,2));
}catch(e){
(0,_common.logError)(e);
}
}


(0,_common.logTask)('configureProject:check projectConfigs',_chalk.default.grey);
if(!_fs.default.existsSync(c.paths.project.projectConfig.dir)){
(0,_common.logWarning)("Looks like your projectConfig folder "+
_chalk.default.white(c.paths.project.projectConfig.dir)+" is missing! Let's create one for you.");

(0,_fileutils.copyFolderContentsRecursiveSync)(templateProjectConfigFolder,c.paths.project.projectConfig.dir);
}

resolve();
});};

var getTemplateOptions=function getTemplateOptions(){return(0,_common.generateOptions)(_templates.templates);};exports.getTemplateOptions=getTemplateOptions;